/*
 * gpsapi.h
 */
#ifndef	_GPSAPI_H
#define	_GPSAPI_H

#if __GNUC__ >= 3
#pragma GCC system_header
#endif

#ifdef  __cplusplus
extern "C" {
#endif

#if defined(_WIN32_WCE) && (_WIN32_WCE >= 0x0500)

#define	GPS_VERSION_CURRENT	1

#define	GPS_MAX_SATELLITES	12
#define	GPS_MAX_PREFIX_NAME	16
#define	GPS_MAX_FRIENDLY_NAME	64

typedef enum {
	GPS_FIX_UNKNOWN = 0,
	GPS_FIX_2D,
	GPS_FIX_3D
} GPS_FIX_TYPE;

typedef enum {
	GPS_FIX_QUALITY_UNKNOWN = 0,
	GPS_FIX_QUALITY_GPS,
	GPS_FIX_QUALITY_DGPS
} GPS_FIX_QUALITY;

typedef enum {
	GPS_FIX_SELECTION_UNKNOWN = 0,
	GPS_FIX_SELECTION_AUTO,
	GPS_FIX_SELECTION_MANUAL
} GPS_FIX_SELECTION;

typedef struct _GPS_DEVICE {
	DWORD		dwVersion;
	DWORD		dwSize;
	DWORD		dwServiceState;
	DWORD		dwDeviceState;
	FILETIME	ftLastDataReceived;
	WCHAR		szGPSDriverPrefix[GPS_MAX_PREFIX_NAME];
	WCHAR		szGPSMultiplexPrefix[GPS_MAX_PREFIX_NAME];
	WCHAR		szGPSFriendlyName[GPS_MAX_FRIENDLY_NAME];
} *PGPS_DEVICE, GPS_DEVICE;


typedef struct _GPS_POSITION {
	DWORD dwVersion;
	DWORD dwSize;

	DWORD dwValidFields;

	DWORD dwFlags;

	SYSTEMTIME stUTCTime;

	double dblLatitude;
	double dblLongitude;
	float  flSpeed;
	float  flHeading;
	double dblMagneticVariation;
	float  flAltitudeWRTSeaLevel;
	float  flAltitudeWRTEllipsoid;

	GPS_FIX_QUALITY     FixQuality;
	GPS_FIX_TYPE        FixType;
	GPS_FIX_SELECTION   SelectionType;
	float flPositionDilutionOfPrecision;
	float flHorizontalDilutionOfPrecision;
	float flVerticalDilutionOfPrecision;

	DWORD dwSatelliteCount;
	DWORD rgdwSatellitesUsedPRNs[GPS_MAX_SATELLITES];

	DWORD dwSatellitesInView;
	DWORD rgdwSatellitesInViewPRNs[GPS_MAX_SATELLITES];
	DWORD rgdwSatellitesInViewElevation[GPS_MAX_SATELLITES];
	DWORD rgdwSatellitesInViewAzimuth[GPS_MAX_SATELLITES];
	DWORD rgdwSatellitesInViewSignalToNoiseRatio[GPS_MAX_SATELLITES];
} GPS_POSITION, *PGPS_POSITION;

DWORD GPSGetPosition(
		HANDLE		hGPSDevice,
		GPS_POSITION	*pGPSPosition,
		DWORD		dwMaximumAge,
		DWORD		dwFlags);

HANDLE GPSOpenDevice(
		HANDLE		hNewLocationData,
		HANDLE		hDeviceStateChange,
		const WCHAR	*szDeviceName,
		DWORD		dwFlags
);

DWORD GPSCloseDevice(HANDLE hGPSDevice);

DWORD GPSGetDeviceState(GPS_DEVICE *pGPSDevice);

/* Values for GPS_POSITION */
#define	GPS_VALID_UTC_TIME			0x00000001	/* If set, the stUTCTime field is valid. */
#define GPS_VALID_LATITUDE			0x00000002 	/* If set, the dblLatitude field is valid. */
#define GPS_VALID_LONGITUDE			0x00000004 	/* If set, the dblLongitude field is valid. */
#define GPS_VALID_SPEED				0x00000008 	/* If set, the flSpeed field is valid. */
#define GPS_VALID_HEADING			0x00000010 	/* If set, the flHeading field is valid. */
#define GPS_VALID_MAGNETIC_VARIATION		0x00000020 	/* If set, the dblMagneticVariation field is valid. */
#define GPS_VALID_ALTITUDE_WRT_SEA_LEVEL	0x00000040 	/* If set, the flAltitudeWRTSeaLevel field is valid. */
#define GPS_VALID_ALTITUDE_WRT_ELLIPSOID	0x00000080 	/* If set, the flAltitudeWRTEllipsoid field is valid. */
#define GPS_VALID_POSITION_DILUTION_OF_PRECISION \
						0x00000100 	/* If set, the flPositionDilutionOfPrecision field is valid. */
#define GPS_VALID_HORIZONTAL_DILUTION_OF_PRECISION \
						0x00000200 	/* If set, the flHorizontalDilutionOfPrecision field is valid. */
#define GPS_VALID_VERTICAL_DILUTION_OF_PRECISION \
						0x00000400 	/* If set, the flVerticalDilutionOfPrecision field is valid. */
#define GPS_VALID_SATELLITE_COUNT		0x00000800 	/* If set, the dwSatelliteCount field is valid. */
#define GPS_VALID_SATELLITES_USED_PRNS		0x00001000 	/* If set, the rgdwSatellitesUsedPRNs field is valid. */
#define GPS_VALID_SATELLITES_IN_VIEW		0x00002000 	/* If set, the dwSatellitesInView field is valid. */
#define GPS_VALID_SATELLITES_IN_VIEW_PRNS	0x00004000 	/* If set, the rgdwSatellitesInViewPRNs field is valid. */
#define GPS_VALID_SATELLITES_IN_VIEW_ELEVATION	0x00008000 	/* If set, the rgdwSatellitesInViewElevation field is valid. */
#define GPS_VALID_SATELLITES_IN_VIEW_AZIMUTH	0x00010000 	/* If set, the rgdwSatellitesInViewAzimuth field is valid. */
#define GPS_VALID_SATELLITES_IN_VIEW_SIGNAL_TO_NOISE_RATIO \
						0x00020000 	/* If set, the rgdwSatellitesInViewSignalToNoiseRatio field is valid. */
#endif

#ifdef  __cplusplus
}
#endif

#endif  /* _GPSAPI_H */

